@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     ActionType,
@@ -205,7 +205,7 @@ _OptionalAssociateFirewallRuleGroupRequestRequestTypeDef = TypedDict(
     "_OptionalAssociateFirewallRuleGroupRequestRequestTypeDef",
     {
         "MutationProtection": MutationProtectionStatusType,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -299,7 +299,7 @@ _RequiredCreateFirewallDomainListRequestRequestTypeDef = TypedDict(
 _OptionalCreateFirewallDomainListRequestRequestTypeDef = TypedDict(
     "_OptionalCreateFirewallDomainListRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -330,7 +330,7 @@ _RequiredCreateFirewallRuleGroupRequestRequestTypeDef = TypedDict(
 _OptionalCreateFirewallRuleGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateFirewallRuleGroupRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -393,16 +393,16 @@ _RequiredCreateResolverEndpointRequestRequestTypeDef = TypedDict(
     "_RequiredCreateResolverEndpointRequestRequestTypeDef",
     {
         "CreatorRequestId": str,
-        "SecurityGroupIds": List[str],
+        "SecurityGroupIds": Sequence[str],
         "Direction": ResolverEndpointDirectionType,
-        "IpAddresses": List["IpAddressRequestTypeDef"],
+        "IpAddresses": Sequence["IpAddressRequestTypeDef"],
     },
 )
 _OptionalCreateResolverEndpointRequestRequestTypeDef = TypedDict(
     "_OptionalCreateResolverEndpointRequestRequestTypeDef",
     {
         "Name": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -434,7 +434,7 @@ _RequiredCreateResolverQueryLogConfigRequestRequestTypeDef = TypedDict(
 _OptionalCreateResolverQueryLogConfigRequestRequestTypeDef = TypedDict(
     "_OptionalCreateResolverQueryLogConfigRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -467,9 +467,9 @@ _OptionalCreateResolverRuleRequestRequestTypeDef = TypedDict(
     "_OptionalCreateResolverRuleRequestRequestTypeDef",
     {
         "Name": str,
-        "TargetIps": List["TargetAddressTypeDef"],
+        "TargetIps": Sequence["TargetAddressTypeDef"],
         "ResolverEndpointId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -648,7 +648,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
     total=False,
 )
@@ -1167,7 +1167,7 @@ ListResolverDnssecConfigsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1219,7 +1219,7 @@ ListResolverEndpointsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1239,7 +1239,7 @@ ListResolverQueryLogConfigAssociationsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "SortBy": str,
         "SortOrder": SortOrderType,
     },
@@ -1262,7 +1262,7 @@ ListResolverQueryLogConfigsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "SortBy": str,
         "SortOrder": SortOrderType,
     },
@@ -1285,7 +1285,7 @@ ListResolverRuleAssociationsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1305,7 +1305,7 @@ ListResolverRulesRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1488,7 +1488,7 @@ ResolverRuleConfigTypeDef = TypedDict(
     "ResolverRuleConfigTypeDef",
     {
         "Name": str,
-        "TargetIps": List["TargetAddressTypeDef"],
+        "TargetIps": Sequence["TargetAddressTypeDef"],
         "ResolverEndpointId": str,
     },
     total=False,
@@ -1530,7 +1530,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1565,7 +1565,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1590,7 +1590,7 @@ UpdateFirewallDomainsRequestRequestTypeDef = TypedDict(
     {
         "FirewallDomainListId": str,
         "Operation": FirewallDomainUpdateOperationType,
-        "Domains": List[str],
+        "Domains": Sequence[str],
     },
 )
 
